spacepy.datamodel.DMWarning — SpacePy v0.1.5 Manual

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »
- datamodel - easy to use general data model »

# spacepy.datamodel.DMWarning

class `spacepy.datamodel.` `DMWarning`

  Warnings class for datamodel, subclassed so it can be set to always

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »
- datamodel - easy to use general data model »